FireOptions

Struct FireOptions 

pub struct FireOptions {
Show 15 fields pub input: InputBam, pub out: String, pub ont: bool, pub human: bool, pub yeast: bool, pub extract: bool, pub all: bool, pub feats_to_text: bool, pub width_bin: i64, pub bin_num: i64, pub best_window_size: i64, pub use_5mc: bool, pub min_msp_length_for_positive_fire_call: i64, pub model: Option<String>, pub fdr_table: Option<String>,
}

Fields

input: InputBamout: String

Output file (BAM by default, table of MSP features if --feats-to-text is used, and bed9 + if `–extract`` is used)

ont: bool

Force the ONT heuristic adjustment for every read in FIRE calling. This adjusts the observed number of m6A counts by adding pseudo counts to account for the single stranded nature of ONT data. ONT reads are auto-detected per read (via aux tags / read name), so this flag is only needed to override detection; reads matching no known platform convention default to PacBio.

human: bool

Use a human model for FIRE calling

yeast: bool

Use a yeast model for FIRE calling

extract: bool

Output just FIRE elements in bed9 format

all: bool

When extracting bed9 format include all MSPs and nucleosomes

feats_to_text: bool

Output FIREs features for training in a table format

width_bin: i64

Width of bin for feature collection

bin_num: i64

Number of bins to collect

best_window_size: i64

Calculate stats for the highest X bp window within each MSP Should be a fair amount higher than the expected linker length.

use_5mc: bool

Use 5mC data in FIREs

min_msp_length_for_positive_fire_call: i64

Minium length of msp to call a FIRE

model: Option<String>

Optional path to a model json file. If not provided ft will use the default model (recommended).

fdr_table: Option<String>

Optional path to a FDR table