pub struct MockFireOptions {
pub bed: String,
pub out: String,
pub read_length: Option<i64>,
pub quality: u8,
pub uncompressed: bool,
pub global: GlobalOpts,
}Fields
bed: StringInput BED file where intervals become FIRE elements. Intervals are grouped into a mock read by chromosome and the 4th column (name), so a name reused across chromosomes yields one read per chromosome.
out: StringOutput BAM file
read_length: Option<i64>Length of mock reads (default: auto-calculated from BED intervals)
quality: u8FIRE quality score to assign (0-255, higher = more confident FIRE call)
uncompressed: boolUncompressed BAM output (default: compressed)
global: GlobalOptsTrait Implementations
Sourceimpl Args for MockFireOptions
impl Args for MockFireOptions
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl Debug for MockFireOptions
impl Debug for MockFireOptions
Sourceimpl FromArgMatches for MockFireOptions
impl FromArgMatches for MockFireOptions
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Auto Trait Implementations
impl Freeze for MockFireOptions
impl RefUnwindSafe for MockFireOptions
impl Send for MockFireOptions
impl Sync for MockFireOptions
impl Unpin for MockFireOptions
impl UnsafeUnpin for MockFireOptions
impl UnwindSafe for MockFireOptions