pub struct PileupOptions {Show 14 fields
pub input: InputBam,
pub rgn: Vec<String>,
pub bed: Option<String>,
pub out: String,
pub m6a: bool,
pub cpg: bool,
pub haps: bool,
pub keep_zeros: bool,
pub per_base: bool,
pub fiber_coverage: bool,
pub shuffle: Option<String>,
pub rolling_max: Option<usize>,
pub no_msp: bool,
pub no_nuc: bool,
}Fields
input: InputBamrgn: Vec<String>Region string(s) to make a pileup of. e.g. chr1:1-1000 or chr1:1-1,000 Can be specified multiple times for multiple regions. If not provided will make a pileup of the whole genome
bed: Option<String>BED file with regions to query. If the BED file has a name column (4th column), the name will be added to each output line for that region.
out: StringOutput file
m6a: boolinclude m6A calls
cpg: boolinclude 5mC calls
haps: boolFor each column add two new columns with the hap1 and hap2 specific data.
keep_zeros: boolKeep zero coverage regions
per_base: boolWrite output one base at a time even if the values do not change
fiber_coverage: boolCalculate coverage starting from the first MSP/NUC to the last MSP/NUC position instead of the complete span of the read alignment.
shuffle: Option<String>Shuffle the fiber-seq data according to a bed file of the shuffled positions of the fiber-seq data
The bed file should have the following format: #chrom shuffled_start shuffled_end read_name original_start
rolling_max: Option<usize>Output a rolling max of the score column over X bases
no_msp: boolNo MSP columns
no_nuc: boolNo NUC columns
Implementations
Sourceimpl PileupOptions
impl PileupOptions
Sourcepub fn effective_fiber_coverage(&self) -> bool
pub fn effective_fiber_coverage(&self) -> bool
--fire-filter bundles --fiber-coverage in addition to the three
filters. Callers should use this in place of reading fiber_coverage
directly so the bundle stays coherent.